package de.ovgu.dke.mocca.tools.streaming;

import java.net.URI;
import java.util.Arrays;
import java.util.Collection;

import org.apache.commons.codec.BinaryDecoder;
import org.apache.commons.codec.DecoderException;
import org.apache.commons.codec.binary.Base64;

import de.ovgu.dke.mocca.api.MoccaException;
import de.ovgu.dke.mocca.api.command.Command;
import de.ovgu.dke.mocca.api.command.CommandHandler;
import de.ovgu.dke.mocca.api.context.Context;
import de.ovgu.dke.mocca.tools.streaming.chunking.Chunk;
import de.ovgu.dke.mocca.tools.streaming.chunking.ChunkConcatenator;
import de.ovgu.dke.mocca.tools.streaming.chunking.ChunkException;
import de.ovgu.dke.mocca.util.ContextUtils;

/**
 * Decodes incoming data chunks and appends them to the stream in the context.
 * 
 * @author Stefan Haun (stefan.haun@ovgu.de)
 */
public class AppendChunkDataHandler implements CommandHandler {
	private static BinaryDecoder decoder = new Base64(0);

	@Override
	public Collection<URI> getAvailableCommands() {
		return Arrays.asList(StreamIdentifiers.CMD_BINARY_APPEND_CHUNK);
	}

	@Override
	public void handleCommand(Command cmd, Context ctx) throws MoccaException {
		// get the chunk concatenator
		final ChunkConcatenator concat = (ChunkConcatenator) ctx
				.getAttribute(StreamIdentifiers.ATTR_CONCAT);

		if (concat == null) {
			ContextUtils.sendError(ctx, "IllegalState",
					"Stream attributes could not be found in context. "
							+ "Has the streaming been prepared correctly?");
			return;
		}

		// get the chunk number
		final Integer chunk_no = ContextUtils.retrieveInteger(ctx, cmd,
				StreamIdentifiers.PARA_CHUNK_NO);
		if (chunk_no == null) {
			ContextUtils.sendError(ctx, "IllegalArgument",
					"missing parameter: " + StreamIdentifiers.PARA_CHUNK_NO);
		}

		// get the data
		final String data = cmd.getParameter(StreamIdentifiers.PARA_DATA);

		if (data == null) {
			ContextUtils.sendError(ctx, "IllegalArgument", "missing argument: "
					+ StreamIdentifiers.PARA_DATA);
			return;
		}

		// add to stream
		try {
			final byte[] decoded = decoder.decode(data.getBytes());
			concat.pushChunk(Chunk.newInstance(decoded, chunk_no));
		} catch (ChunkException e) {
			ContextUtils.sendError(ctx, "InternalError", "Error adding chunk: "
					+ e.getMessage());
			e.printStackTrace();
			return;
		} catch (DecoderException e) {
			ContextUtils.sendError(ctx, "InternalError",
					"Error decoding chunk: " + e.getMessage());
			e.printStackTrace();
			return;
		}

		// finished.
	}

}
