/*
 * Copyright 2012 Stefan Haun, Andreas Nürnberger
 * 
 *      Data and Knowledge Engineering Group, 
 * 		Faculty of Computer Science,
 *		Otto-von-Guericke University,
 *		Magdeburg, Germany
 *
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package de.ovgu.dke.mocca.tools.streaming;

import java.net.URI;

/**
 * Constants for the streaming methods.
 * 
 * @author Stefan Haun (stefan.haun@ovgu.de)
 * 
 */
public class StreamIdentifiers {
	public static final String STREAM_PREFIX = "http://dke.ovgu.de/mocca/tools/stream";

	public static final URI CMD_BINARY_SEND = URI.create(STREAM_PREFIX
			+ "/send");
	public static final URI CMD_BINARY_START = URI.create(STREAM_PREFIX
			+ "/start");
	public static final URI CMD_BINARY_RECEIVE = URI.create(STREAM_PREFIX
			+ "/receive");
	public static final URI CMD_BINARY_APPEND_CHUNK = URI.create(STREAM_PREFIX
			+ "/append_chunk");
	public static final String PARA_CHUNK_SIZE = STREAM_PREFIX + "#chunk-size";
	public static final String PARA_CHUNK_NO = STREAM_PREFIX + "#chunk-no";
	public static final String PARA_ENCODING = STREAM_PREFIX + "#encoding";
	public static final String PARA_MIME_TYPE = STREAM_PREFIX + "#mime-type";
	public static final String PARA_LENGTH = STREAM_PREFIX + "#length";
	public static final String PARA_NAME = STREAM_PREFIX + "#name";
	public static final String PARA_DATA = STREAM_PREFIX + "#data";

	public static final String ATTR_STREAM = STREAM_PREFIX + "#stream";
	public static final String ATTR_DECODER = STREAM_PREFIX + "#decoder";
	public static final String ATTR_CHUNKS = STREAM_PREFIX + "#chunks";
	public static final String ATTR_CONCAT = STREAM_PREFIX + "#concat";

	/**
	 * The type of the stream (one of {@link StreamType}).
	 */
	public static final URI PROPERTY_TYPE = URI.create(STREAM_PREFIX + "/type");

	private StreamIdentifiers() {
		// instances are not allowed!
	}
}
